@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Test::CleanNamespaces; # git description: v0.20-4-g83da0a4
+package Test::CleanNamespaces; # git description: v0.22-6-g67eaa09
 # ABSTRACT: Check for uncleaned imports
 # KEYWORDS: testing namespaces clean dirty imports exports subroutines methods
 
-our $VERSION = '0.21';
+our $VERSION = '0.23';
 
 use Module::Runtime ();
 use Sub::Identify ();
@@ -152,8 +152,9 @@ sub find_modules {
                 my $file = $_;
                 return
                     unless $file =~ s/\.pm$//;
-                $file = File::Spec->abs2rel($file, $top);
-                push @modules, join '::' => File::Spec->splitdir($_);
+                push @modules, join '::' => File::Spec->splitdir(
+                    File::Spec->abs2rel(File::Spec->rel2abs($file, '.'), $top)
+                );
             },
         }, $top);
     }
@@ -187,7 +188,7 @@ Test::CleanNamespaces - Check for uncleaned imports
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
